@@ -2,11 +2,14 @@ from __future__ import absolute_import
 
 # This file is excluded from flake8 checking in setup.cfg
 
-from .actions import *
+from .annotations import *
 from .axes import *
+from .callbacks import *
+from .component import *
 from .formatters import *
 from .glyphs import *
 from .grids import *
+from .images import *
 from .map_plots import *
 from .markers import *
 from .mappers import *
@@ -15,6 +18,6 @@ from .ranges import *
 from .renderers import *
 from .sources import *
 from .tickers import *
+from .tiles import *
 from .tools import *
-from .widget import *
 from .widgets import *
