@@ -5,28 +5,22 @@ from __future__ import absolute_import
 
 import six
 
-from ...properties import Bool, Int, Float, String, Date, RelativeDelta, Enum, List, Dict, Tuple, Either, Instance
-from ..actions import Callback
-from ..widget import Widget
+from ...core.properties import abstract
+from ...core.properties import Bool, Int, Float, String, Date, RelativeDelta, Enum, List, Dict, Tuple, Either, Instance
+from ..callbacks import Callback
+from .widget import Widget
 
+@abstract
 class InputWidget(Widget):
     """ Abstract base class for input widgets. `InputWidget`` is not
     generally useful to instantiate on its own.
 
     """
 
-    title = String(help="""
+    title = String(default="", help="""
     Widget's label.
     """)
 
-    name = String(help="""
-    Widget's name.
-    """)
-
-    callback = Instance(Callback, help="""
-    A callback to run in the browser whenever the input's value changes.
-    """)
-
     @classmethod
     def coerce_value(cls, val):
         prop_obj = cls.lookup('value')
@@ -54,16 +48,21 @@ class InputWidget(Widget):
 class TextInput(InputWidget):
     """ Single-line input widget. """
 
-    value = String(help="""
+    value = String(default="", help="""
     Initial or entered text value.
     """)
 
+    callback = Instance(Callback, help="""
+    A callback to run in the browser whenever the user unfocuses the TextInput
+    widget by hitting Enter or clicking outside of the text box area.
+    """)
+
 class AutocompleteInput(TextInput):
     """ Single-line input widget with auto-completion. """
 
     completions = List(String, help="""
     A list of completion strings. This will be used to guide the
-    user when he types-in a value.
+    user upon typing the beginning of a desired value.
     """)
 
 class Select(InputWidget):
@@ -75,10 +74,15 @@ class Select(InputWidget):
     Available selection options.
     """)
 
-    value = String(help="""
+    value = String(default="", help="""
     Initial or selected value.
     """)
 
+    callback = Instance(Callback, help="""
+    A callback to run in the browser whenever the current Select dropdown
+    value changes.
+    """)
+
     @classmethod
     def create(self, *args, **kwargs):
         options = kwargs.pop('options', [])
@@ -90,15 +94,24 @@ class Select(InputWidget):
         kwargs['options'] = new_options
         return super(Select, self).create(*args, **kwargs)
 
-class MultiSelect(Select):
+class MultiSelect(InputWidget):
     """ Multi-select widget.
 
     """
 
+    options = List(Either(String, Dict(String, String)), help="""
+    Available selection options.
+    """)
+
     value = List(String, help="""
     Initial or selected values.
     """)
 
+    callback = Instance(Callback, help="""
+    A callback to run in the browser whenever the current dropdown value
+    changes.
+    """)
+
     @classmethod
     def create(self, *args, **kwargs):
         options = kwargs.pop('options', [])
@@ -115,19 +128,19 @@ class Slider(InputWidget):
 
     """
 
-    value = Float(help="""
+    value = Float(default=0.5, help="""
     Initial or selected value.
     """)
 
-    start = Float(help="""
+    start = Float(default=0, help="""
     The minimum allowable value.
     """)
 
-    end = Float(help="""
+    end = Float(default=1, help="""
     The maximum allowable value.
     """)
 
-    step = Float(help="""
+    step = Float(default=0.1, help="""
     The step between consecutive values.
     """)
 
@@ -135,6 +148,10 @@ class Slider(InputWidget):
     Orient the slider either horizontally (default) or vertically.
     """)
 
+    callback = Instance(Callback, help="""
+    A callback to run in the browser whenever the current Slider value changes.
+    """)
+
 class DateRangeSlider(InputWidget):
     """ Slider-based date range selection widget.
 
@@ -176,6 +193,10 @@ class DateRangeSlider(InputWidget):
     do nothing).
     """)
 
+    callback = Instance(Callback, help="""
+    A callback to run in the browser whenever either slider's value changes.
+    """)
+
 class DatePicker(InputWidget):
     """ Calendar-based date picker widget.
 
@@ -192,3 +213,7 @@ class DatePicker(InputWidget):
     max_date = Date(default=None, help="""
     Optional latest allowable date.
     """)
+
+    callback = Instance(Callback, help="""
+    A callback to run in the browser whenever the current date value changes.
+    """)
