@@ -5,9 +5,6 @@ for the property attribute, including cross links to the relevant
 property types. Additionally, any per-attribute docstrings are
 also displayed.
 
-Usage
------
-
 This directive takes the path to an attribute on a Bokeh
 model class as an argument::
 
@@ -18,14 +15,12 @@ Examples
 
 For the following definition of ``bokeh.sphinxext.sample.Bar``::
 
-    class Bar(PlotObject):
+    class Bar(Model):
         ''' This is a Bar model. '''
         thing = List(Int, help="doc for thing")
 
 the above usage yields the output:
 
-----
-
     .. bokeh-prop:: bokeh.sphinxext.sample.Bar.thing
 
 """
@@ -43,8 +38,8 @@ import jinja2
 from sphinx.util.compat import Directive
 from sphinx.util.nodes import nested_parse_with_titles
 
-from bokeh.plot_object import Viewable
-import bokeh.properties
+from bokeh.model import Viewable
+import bokeh.core.properties
 
 
 PROP_TEMPLATE = jinja2.Template(u"""
@@ -58,8 +53,8 @@ PROP_TEMPLATE = jinja2.Template(u"""
 """)
 
 PROP_NAMES = [
-    name for name, cls in bokeh.properties.__dict__.items()
-    if isinstance(cls, type) and issubclass(cls, bokeh.properties.Property)
+    name for name, cls in bokeh.core.properties.__dict__.items()
+    if isinstance(cls, type) and issubclass(cls, bokeh.core.properties.Property)
 ]
 PROP_NAMES.sort(reverse=True, key=len)
 
@@ -108,7 +103,7 @@ class BokehPropDirective(Directive):
 
     def _get_type_info(self, prop):
         desc = str(prop)
-        template = ":class:`~bokeh.properties.%s`\ "
+        template = ":class:`~bokeh.core.properties.%s`\ "
         # some of the property names are substrings of other property names
         # so first go through greedily replacing the longest possible match
         # with a unique id (PROP_NAMES is reverse sorted by length)
