@@ -1,22 +1,20 @@
 from __future__ import print_function
 
-from bokeh.browserlib import view
-from bokeh.models import ColumnDataSource, DataRange1d, Plot, LinearAxis, Grid, GlyphRenderer, Circle, HoverTool, BoxSelectTool
-from bokeh.models.widgets import (
-    Select, HBox, VBox, DataTable, TableColumn, StringFormatter,
-    NumberFormatter, StringEditor, IntEditor, NumberEditor, SelectEditor)
+from bokeh.client import push_session
 from bokeh.document import Document
-from bokeh.session import Session
+from bokeh.models import (
+    ColumnDataSource, DataRange1d, Plot, LinearAxis, Grid,
+    Circle, HoverTool, BoxSelectTool
+)
+from bokeh.models.widgets import (
+    Select, DataTable, TableColumn, StringFormatter, HBox, VBox,
+    NumberFormatter, StringEditor, IntEditor, NumberEditor, SelectEditor)
 from bokeh.sampledata.autompg2 import autompg2 as mpg
 
 class DataTables(object):
 
     def __init__(self):
         self.document = Document()
-        self.session = Session()
-        self.session.use_doc('data_tables_server')
-        self.session.load_document(self.document)
-
         self.manufacturer_filter = None
         self.model_filter = None
         self.transmission_filter = None
@@ -26,8 +24,8 @@ class DataTables(object):
         self.source = ColumnDataSource()
         self.update_data()
 
-        self.document.add(self.create())
-        self.session.store_document(self.document)
+        self.document.add_root((self.create()))
+        self.session = push_session(self.document)
 
     def create(self):
         manufacturers = sorted(mpg["manufacturer"].unique())
@@ -61,18 +59,21 @@ class DataTables(object):
         ]
         data_table = DataTable(source=self.source, columns=columns, editable=True)
 
-        xdr = DataRange1d()
-        ydr = DataRange1d()
-        plot = Plot(title=None, x_range=xdr, y_range=ydr, plot_width=800, plot_height=300)
-        xaxis = LinearAxis(plot=plot)
-        plot.below.append(xaxis)
-        yaxis = LinearAxis(plot=plot)
-        ygrid = Grid(plot=plot, dimension=1, ticker=yaxis.ticker)
-        plot.left.append(yaxis)
+        plot = Plot(title=None, x_range= DataRange1d(), y_range=DataRange1d(), plot_width=1000, plot_height=300)
+
+        # Set up x & y axis
+        plot.add_layout(LinearAxis(), 'below')
+        yaxis = LinearAxis()
+        plot.add_layout(yaxis, 'left')
+        plot.add_layout(Grid(dimension=1, ticker=yaxis.ticker))
+
+        # Add Glyphs
         cty_glyph = Circle(x="index", y="cty", fill_color="#396285", size=8, fill_alpha=0.5, line_alpha=0.5)
         hwy_glyph = Circle(x="index", y="hwy", fill_color="#CE603D", size=8, fill_alpha=0.5, line_alpha=0.5)
-        cty = GlyphRenderer(data_source=self.source, glyph=cty_glyph)
-        hwy = GlyphRenderer(data_source=self.source, glyph=hwy_glyph)
+        cty = plot.add_glyph(self.source, cty_glyph)
+        hwy = plot.add_glyph(self.source, hwy_glyph)
+
+        # Add the tools
         tooltips = [
             ("Manufacturer", "@manufacturer"),
             ("Model", "@model"),
@@ -83,35 +84,37 @@ class DataTables(object):
             ("Drive", "@drv"),
             ("Class", "@class"),
         ]
-        cty_hover_tool = HoverTool(plot=plot, renderers=[cty], tooltips=tooltips + [("City MPG", "@cty")])
-        hwy_hover_tool = HoverTool(plot=plot, renderers=[hwy], tooltips=tooltips + [("Highway MPG", "@hwy")])
-        select_tool = BoxSelectTool(plot=plot, renderers=[cty, hwy], dimensions=['width'])
-        plot.tools.extend([cty_hover_tool, hwy_hover_tool, select_tool])
-        plot.renderers.extend([cty, hwy, ygrid])
+        cty_hover_tool = HoverTool(renderers=[cty], tooltips=tooltips + [("City MPG", "@cty")])
+        hwy_hover_tool = HoverTool(renderers=[hwy], tooltips=tooltips + [("Highway MPG", "@hwy")])
+        select_tool = BoxSelectTool(renderers=[cty, hwy], dimensions=['width'])
+        plot.add_tools(cty_hover_tool, hwy_hover_tool, select_tool)
 
-        controls = VBox(children=[manufacturer_select, model_select, transmission_select, drive_select, class_select], width=200)
+
+        controls = VBox(children=[
+            manufacturer_select, model_select, transmission_select,
+             drive_select, class_select])
         top_panel = HBox(children=[controls, plot])
         layout = VBox(children=[top_panel, data_table])
 
         return layout
 
-    def on_manufacturer_change(self, obj, attr, _, value):
+    def on_manufacturer_change(self, attr, _, value):
         self.manufacturer_filter = None if value == "All" else value
         self.update_data()
 
-    def on_model_change(self, obj, attr, _, value):
+    def on_model_change(self, attr, _, value):
         self.model_filter = None if value == "All" else value
         self.update_data()
 
-    def on_transmission_change(self, obj, attr, _, value):
+    def on_transmission_change(self, attr, _, value):
         self.transmission_filter = None if value == "All" else value
         self.update_data()
 
-    def on_drive_change(self, obj, attr, _, value):
+    def on_drive_change(self, attr, _, value):
         self.drive_filter = None if value == "All" else value
         self.update_data()
 
-    def on_class_change(self, obj, attr, _, value):
+    def on_class_change(self, attr, _, value):
         self.class_filter = None if value == "All" else value
         self.update_data()
 
@@ -128,14 +131,12 @@ class DataTables(object):
         if self.class_filter:
             df = df[df["class"] == self.class_filter]
         self.source.data = ColumnDataSource.from_df(df)
-        self.session.store_document(self.document)
 
     def run(self, do_view=False, poll_interval=0.5):
-        link = self.session.object_link(self.document.context)
-        print("Please visit %s to see the plots" % link)
-        if do_view: view(link)
-        print("\npress ctrl-C to exit")
-        self.session.poll_document(self.document)
+        if do_view:
+            self.session.show()
+
+        self.session.loop_until_closed()
 
 if __name__ == "__main__":
     data_tables = DataTables()
