@@ -10,7 +10,7 @@ import scipy.ndimage as im
 from bokeh.document import Document
 from bokeh.embed import file_html
 from bokeh.resources import INLINE
-from bokeh.browserlib import view
+from bokeh.util.browser import view
 
 from bokeh.models.glyphs import Line, Patches
 from bokeh.models.widgets import VBox
@@ -131,7 +131,7 @@ altitude = altitude_profile(data)
 layout = VBox(children=[altitude, trail])
 
 doc = Document()
-doc.add(layout)
+doc.add_root(layout)
 
 if __name__ == "__main__":
     filename = "trail.html"
