@@ -1,20 +1,23 @@
 import numpy as np
-from six.moves import zip
 
 from bokeh.plotting import figure, show, output_file
 
 N = 4000
-
 x = np.random.random(size=N) * 100
 y = np.random.random(size=N) * 100
 radii = np.random.random(size=N) * 1.5
-colors = ["#%02x%02x%02x" % (r, g, 150) for r, g in zip(np.floor(50+2*x), np.floor(30+2*y))]
+colors = [
+    "#%02x%02x%02x" % (int(r), int(g), 150) for r, g in zip(50+2*x, 30+2*y)
+]
 
 TOOLS="resize,crosshair,pan,wheel_zoom,box_zoom,reset,tap,previewsave,box_select,poly_select,lasso_select"
 
+p = figure(tools=TOOLS)
+
+p.scatter(x, y, radius=radii,
+          fill_color=colors, fill_alpha=0.6,
+          line_color=None)
+
 output_file("color_scatter.html", title="color_scatter.py example")
 
-p = figure(tools=TOOLS)
-p.scatter(x, y, radius=radii, fill_color=colors, fill_alpha=0.6, line_color=None)
-
 show(p)  # open a browser
