@@ -1,16 +1,17 @@
-from bokeh.sampledata.iris import flowers
+
 from bokeh.plotting import figure, show, output_file
+from bokeh.sampledata.iris import flowers
 
 colormap = {'setosa': 'red', 'versicolor': 'green', 'virginica': 'blue'}
-flowers['color'] = flowers['species'].map(lambda x: colormap[x])
-
-output_file("iris.html", title="iris.py example")
+colors = [colormap[x] for x in flowers['species']]
 
 p = figure(title = "Iris Morphology")
 p.xaxis.axis_label = 'Petal Length'
 p.yaxis.axis_label = 'Petal Width'
 
 p.circle(flowers["petal_length"], flowers["petal_width"],
-        color=flowers["color"], fill_alpha=0.2, size=10, )
+         color=colors, fill_alpha=0.2, size=10)
+
+output_file("iris.html", title="iris.py example")
 
 show(p)
