@@ -1,7 +1,8 @@
+
 import numpy as np
 from scipy.integrate import odeint
 
-from bokeh.plotting import *
+from bokeh.plotting import figure, show, output_file
 
 sigma = 10
 rho = 28
@@ -27,11 +28,11 @@ xprime = np.cos(theta) * x - np.sin(theta) * y
 
 colors = ["#C6DBEF", "#9ECAE1", "#6BAED6", "#4292C6", "#2171B5", "#08519C", "#08306B",]
 
-output_file("lorenz.html", title="lorenz.py example")
-
 p = figure(title="lorenz example")
 
 p.multi_line(np.array_split(xprime, 7), np.array_split(z, 7),
-           line_color=colors, line_alpha=0.8, line_width=1.5)
+             line_color=colors, line_alpha=0.8, line_width=1.5)
+
+output_file("lorenz.html", title="lorenz.py example")
 
 show(p)  # open a browser
